@@ -4,7 +4,10 @@ import time
 
 from enum import Enum
 from threading import Thread, Event
+from typing import List
 
+from platypush.context import get_bus
+from platypush.message.event.light import LightAnimationStartedEvent, LightAnimationStoppedEvent
 from platypush.plugins import action
 from platypush.plugins.light import LightPlugin
 from platypush.utils import set_thread_name
@@ -17,6 +20,12 @@ class LightHuePlugin(LightPlugin):
     Requires:
 
         * **phue** (``pip install phue``)
+
+    Triggers:
+
+        - :class:`platypush.message.event.light.LightAnimationStartedEvent` when an animation is started.
+        - :class:`platypush.message.event.light.LightAnimationStoppedEvent` when an animation is stopped.
+
     """
 
     MAX_BRI = 255
@@ -154,7 +163,13 @@ class LightHuePlugin(LightPlugin):
 
         """
 
-        return self.bridge.get_scene()
+        return {
+            id: {
+                'id': id,
+                **scene,
+            }
+            for id, scene in self.bridge.get_scene().items()
+        }
 
     @action
     def get_lights(self):
@@ -195,7 +210,13 @@ class LightHuePlugin(LightPlugin):
 
         """
 
-        return self.bridge.get_light()
+        return {
+            id: {
+                'id': id,
+                **light,
+            }
+            for id, light in self.bridge.get_light().items()
+        }
 
     @action
     def get_groups(self):
@@ -247,7 +268,13 @@ class LightHuePlugin(LightPlugin):
 
         """
 
-        return self.bridge.get_group()
+        return {
+            id: {
+                'id': id,
+                **group,
+            }
+            for id, group in self.bridge.get_group().items()
+        }
 
     @action
     def get_animations(self):
@@ -720,33 +747,36 @@ class LightHuePlugin(LightPlugin):
         :param duration: Animation duration in seconds (default: None, i.e. continue until stop)
         :type duration: float
 
-        :param hue_range: If you selected a color color_transition.html, this will specify the hue range of your color color_transition.html.
+        :param hue_range: If you selected a ``color_transition``, this will specify the hue range of your color ``color_transition``.
             Default: [0, 65535]
         :type hue_range: list[int]
 
-        :param sat_range: If you selected a color color_transition.html, this will specify the saturation range of your color
-            color_transition.html. Default: [0, 255]
+        :param sat_range: If you selected a color ``color_transition``, this will specify the saturation range of your color
+            ``color_transition``. Default: [0, 255]
         :type sat_range: list[int]
 
-        :param bri_range: If you selected a color color_transition.html, this will specify the brightness range of your color
-            color_transition.html. Default: [254, 255] :type bri_range: list[int]
+        :param bri_range: If you selected a color ``color_transition``, this will specify the brightness range of your color
+            ``color_transition``. Default: [254, 255] :type bri_range: list[int]
 
         :param lights: Lights to control (names, IDs or light objects). Default: plugin default lights
         :param groups: Groups to control (names, IDs or group objects). Default: plugin default groups
 
-        :param hue_step: If you selected a color color_transition.html, this will specify by how much the color hue will change
+        :param hue_step: If you selected a color ``color_transition``, this will specify by how much the color hue will change
             between iterations. Default: 1000 :type hue_step: int
 
-        :param sat_step: If you selected a color color_transition.html, this will specify by how much the saturation will change
+        :param sat_step: If you selected a color ``color_transition``, this will specify by how much the saturation will change
             between iterations. Default: 2 :type sat_step: int
 
-        :param bri_step: If you selected a color color_transition.html, this will specify by how much the brightness will change
+        :param bri_step: If you selected a color ``color_transition``, this will specify by how much the brightness will change
             between iterations. Default: 1 :type bri_step: int
 
         :param transition_seconds: Time between two transitions or blinks in seconds. Default: 1.0
         :type transition_seconds: float
         """
 
+        self.stop_animation()
+        self._animation_stop.clear()
+
         if bri_range is None:
             bri_range = [self.MAX_BRI - 1, self.MAX_BRI]
         if sat_range is None:
@@ -801,9 +831,6 @@ class LightHuePlugin(LightPlugin):
             if animation == self.Animation.COLOR_TRANSITION:
                 for (light, attrs) in lights.items():
                     for (attr, value) in attrs.items():
-                        attr_range = [0, 0]
-                        attr_step = 0
-
                         if attr == 'hue':
                             attr_range = hue_range
                             attr_step = hue_step
@@ -813,6 +840,8 @@ class LightHuePlugin(LightPlugin):
                         elif attr == 'sat':
                             attr_range = sat_range
                             attr_step = sat_step
+                        else:
+                            continue
 
                         lights[light][attr] = ((value - attr_range[0] + attr_step) %
                                                (attr_range[1] - attr_range[0] + 1)) + \
@@ -831,25 +860,18 @@ class LightHuePlugin(LightPlugin):
 
         def _animate_thread(lights):
             set_thread_name('HueAnimate')
-            self.logger.info('Starting {} animation'.format(
-                animation, (lights or groups)))
+            get_bus().post(LightAnimationStartedEvent(lights=lights, groups=groups, animation=animation))
 
             lights = _initialize_light_attrs(lights)
             animation_start_time = time.time()
             stop_animation = False
 
-            while True:
-                if stop_animation or \
-                        (duration and time.time() - animation_start_time > duration):
-                    break
-
+            while not stop_animation and not (duration and time.time() - animation_start_time > duration):
                 try:
                     if animation == self.Animation.COLOR_TRANSITION:
                         for (light, attrs) in lights.items():
                             self.logger.debug('Setting {} to {}'.format(light, attrs))
                             self.bridge.set_light(light, attrs)
-                            stop_animation = _should_stop()
-                            if stop_animation: break
                     elif animation == self.Animation.BLINK:
                         conf = lights[list(lights.keys())[0]]
                         self.logger.debug('Setting lights to {}'.format(conf))
@@ -859,26 +881,67 @@ class LightHuePlugin(LightPlugin):
                         else:
                             self.bridge.set_light(lights.keys(), conf)
 
-                        stop_animation = _should_stop()
-                        if stop_animation: break
+                    if transition_seconds:
+                        time.sleep(transition_seconds)
+
+                    stop_animation = _should_stop()
                 except Exception as e:
                     self.logger.warning(e)
                     time.sleep(2)
 
                 lights = _next_light_attrs(lights)
 
-            self.logger.info('Stopping animation')
+            get_bus().post(LightAnimationStoppedEvent(lights=lights, groups=groups, animation=animation))
             self.animation_thread = None
 
-        self.stop_animation()
-        self._animation_stop.clear()
         self.animation_thread = Thread(target=_animate_thread,
                                        name='HueAnimate',
                                        args=(lights,))
         self.animation_thread.start()
 
-    def status(self):
-        # TODO
-        pass
+    @property
+    def switches(self) -> List[dict]:
+        """
+        :returns: Implements :meth:`platypush.plugins.switch.SwitchPlugin.switches` and returns the status of the
+            configured lights. Example:
+
+            .. code-block:: json
+
+                [
+                    {
+                        "id": "3",
+                        "name": "Lightbulb 1",
+                        "on": true,
+                        "bri": 254,
+                        "hue": 1532,
+                        "sat": 215,
+                        "effect": "none",
+                        "xy": [
+                            0.6163,
+                            0.3403
+                        ],
+                        "ct": 153,
+                        "alert": "none",
+                        "colormode": "hs",
+                        "reachable": true
+                        "type": "Extended color light",
+                        "modelid": "LCT001",
+                        "manufacturername": "Philips",
+                        "uniqueid": "00:11:22:33:44:55:66:77-88",
+                        "swversion": "5.105.0.21169"
+                    }
+                ]
+
+        """
+
+        return [
+            {
+                'id': id,
+                **light.pop('state', {}),
+                **light,
+            }
+            for id, light in self.bridge.get_light().items()
+        ]
+
 
 # vim:sw=4:ts=4:et:
